<a href="http://pythoninchemistry.org/pylj"><img src="https://github.com/arm61/pylj/blob/master/logo/logo.png?raw=true" width= "80%"/></a>

## Visit the [pylj](http://pythoninchemistry.org/pylj) webpage for more information about pylj.

To build from source:

```python 

pip install -r requirements.txt

python setup.py build

python setup.py install

python setup.py test

```
Check out our publication in the [Journal of Open Source Education](http://jose.theoj.org/papers/58daa1a1a564dc8e0f99ffcdae20eb1d) to find out more about pylj. 

Be aware! pylj runs within a [Jupyter notebook](http://jupyter.org/), and therefore requires this to run. We advise installing [anaconda python](https://anaconda.org/) as this includes many required libraries as well as the Jupyter notebooks framework.

If you need any help using pylj contact arm61 in the [pylj/HELP gitter chatroom](https://gitter.im/pylj/HELP).

Check out some [examples](https://github.com/arm61/pylj/tree/master/examples) of how pylj can be used in undergraduate teaching exercises. 

[![status](http://jose.theoj.org/papers/58daa1a1a564dc8e0f99ffcdae20eb1d/status.svg)](http://jose.theoj.org/papers/58daa1a1a564dc8e0f99ffcdae20eb1d)
[![DOI](https://zenodo.org/badge/119863480.svg)](https://zenodo.org/badge/latestdoi/119863480)
[![Documentation Status](https://readthedocs.org/projects/pylj/badge/?version=latest)](http://pylj.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/pylj.svg)](https://badge.fury.io/py/pylj)
[![Build Status](https://travis-ci.org/arm61/pylj.svg?branch=master)](https://travis-ci.org/arm61/pylj)
[![Coverage Status](https://coveralls.io/repos/github/arm61/pylj/badge.svg?branch=master)](https://coveralls.io/github/arm61/pylj?branch=master)
[![Gitter chat](https://badges.gitter.im/gitterHQ/gitter.png)](https://gitter.im/pylj/Lobby#)
